
A package offering a simple interface to read and write audio and image data.
This package was created to use [media
computation](http://coweb.cc.gatech.edu/mediaComp-teach) methods in teaching
introductory programming at Davidson College, Davidson, NC.
